@@ -14,6 +14,7 @@ use const PHP_SAPI;
 use const PHP_VERSION;
 use function array_diff;
 use function array_map;
+use function array_merge;
 use function assert;
 use function class_exists;
 use function count;
@@ -151,6 +152,8 @@ final class TestRunner extends BaseTestRunner
 
         $this->handleConfiguration($arguments);
 
+        $warnings = array_merge($warnings, $arguments['warnings']);
+
         if (is_int($arguments['columns']) && $arguments['columns'] < 16) {
             $arguments['columns']   = 16;
             $tooFewColumnsRequested = true;
@@ -245,8 +248,8 @@ final class TestRunner extends BaseTestRunner
 
         unset($listener, $listenerNeeded);
 
-        if (!$arguments['convertDeprecationsToExceptions']) {
-            $result->convertDeprecationsToExceptions(false);
+        if ($arguments['convertDeprecationsToExceptions']) {
+            $result->convertDeprecationsToExceptions(true);
         }
 
         if (!$arguments['convertErrorsToExceptions']) {
@@ -889,6 +892,10 @@ final class TestRunner extends BaseTestRunner
             $arguments['configurationObject'] = (new Loader)->load($arguments['configuration']);
         }
 
+        if (!isset($arguments['warnings'])) {
+            $arguments['warnings'] = [];
+        }
+
         $arguments['debug']     = $arguments['debug'] ?? false;
         $arguments['filter']    = $arguments['filter'] ?? false;
         $arguments['listeners'] = $arguments['listeners'] ?? [];
@@ -1094,7 +1101,7 @@ final class TestRunner extends BaseTestRunner
         $arguments['cacheResult']                                     = $arguments['cacheResult'] ?? true;
         $arguments['colors']                                          = $arguments['colors'] ?? DefaultResultPrinter::COLOR_DEFAULT;
         $arguments['columns']                                         = $arguments['columns'] ?? 80;
-        $arguments['convertDeprecationsToExceptions']                 = $arguments['convertDeprecationsToExceptions'] ?? true;
+        $arguments['convertDeprecationsToExceptions']                 = $arguments['convertDeprecationsToExceptions'] ?? false;
         $arguments['convertErrorsToExceptions']                       = $arguments['convertErrorsToExceptions'] ?? true;
         $arguments['convertNoticesToExceptions']                      = $arguments['convertNoticesToExceptions'] ?? true;
         $arguments['convertWarningsToExceptions']                     = $arguments['convertWarningsToExceptions'] ?? true;
@@ -1167,7 +1174,8 @@ final class TestRunner extends BaseTestRunner
             $filterFactory->addFilter(
                 new ReflectionClass(IncludeGroupFilterIterator::class),
                 array_map(
-                    static function (string $name): string {
+                    static function (string $name): string
+                    {
                         return '__phpunit_covers_' . $name;
                     },
                     $arguments['testsCovering']
@@ -1179,7 +1187,8 @@ final class TestRunner extends BaseTestRunner
             $filterFactory->addFilter(
                 new ReflectionClass(IncludeGroupFilterIterator::class),
                 array_map(
-                    static function (string $name): string {
+                    static function (string $name): string
+                    {
                         return '__phpunit_uses_' . $name;
                     },
                     $arguments['testsUsing']
