@@ -10,6 +10,7 @@
 namespace PHPUnit\TestFixture;
 
 use IteratorAggregate;
+use ReturnTypeWillChange;
 use Traversable;
 
 class TestIteratorAggregate2 implements IteratorAggregate
@@ -21,6 +22,7 @@ class TestIteratorAggregate2 implements IteratorAggregate
         $this->traversable = $traversable;
     }
 
+    #[ReturnTypeWillChange]
     public function getIterator()
     {
         return $this->traversable;
