@@ -7,4 +7,4 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-require __DIR__ . '/Greeter.php';
+require_once __DIR__ . '/Greeter.php';
