@@ -1339,7 +1339,8 @@ XML;
     {
         $this->assertThat(
             null,
-            $this->callback(static function ($other) {
+            $this->callback(static function ($other)
+            {
                 return true;
             })
         );
@@ -2029,7 +2030,8 @@ XML;
 
     public function testCallableTypeCanBeAsserted(): void
     {
-        $this->assertIsCallable(static function (): void {
+        $this->assertIsCallable(static function (): void
+        {
         });
 
         try {
@@ -2198,7 +2200,8 @@ XML;
         $this->assertIsNotCallable(null);
 
         try {
-            $this->assertIsNotCallable(static function (): void {
+            $this->assertIsNotCallable(static function (): void
+            {
             });
         } catch (AssertionFailedError $e) {
             return;
