@@ -21,6 +21,7 @@ use PHPUnit\TestFixture\ClassWithStaticMethod;
 use PHPUnit\TestFixture\ClassWithStaticReturnTypes;
 use PHPUnit\TestFixture\ClassWithUnionReturnTypes;
 use PHPUnit\TestFixture\ExampleTrait;
+use PHPUnit\TestFixture\InterfaceWithMethodsThatDeclareBooleanReturnTypes;
 use PHPUnit\TestFixture\InterfaceWithStaticMethod;
 use PHPUnit\TestFixture\MethodCallback;
 use PHPUnit\TestFixture\MethodCallbackByReference;
@@ -595,7 +596,8 @@ final class MockObjectTest extends TestCase
         $mock->method('doSomethingElse')
              ->will(
                  $this->returnCallback(
-                     static function () use (&$actualArguments): void {
+                     static function () use (&$actualArguments): void
+                     {
                          $actualArguments = \func_get_args();
                      }
                  )
@@ -622,7 +624,8 @@ final class MockObjectTest extends TestCase
         $mock->method('doSomethingElse')
              ->will(
                  $this->returnCallback(
-                     static function () use (&$actualArguments): void {
+                     static function () use (&$actualArguments): void
+                     {
                          $actualArguments = \func_get_args();
                      }
                  )
@@ -849,7 +852,8 @@ final class MockObjectTest extends TestCase
 
         $foo->method('bar')
             ->will($this->returnCallback(
-                static function (&$a, &$b, $c): void {
+                static function (&$a, &$b, $c): void
+                {
                     $b = 1;
                 }
             ));
@@ -977,6 +981,7 @@ final class MockObjectTest extends TestCase
     /**
      * @see    https://github.com/sebastianbergmann/phpunit-mock-objects/issues/171
      * @ticket 171
+     * @requires PHP < 8.1
      */
     public function testStubForClassThatImplementsSerializableCanBeCreatedWithoutInvokingTheConstructor(): void
     {
@@ -1030,7 +1035,8 @@ final class MockObjectTest extends TestCase
         $callCount             = 0;
 
         $mock->expects($this->exactly($expectedNumberOfCalls))->method('bar')
-            ->with($this->callback(static function ($argument) use (&$callCount) {
+            ->with($this->callback(static function ($argument) use (&$callCount)
+            {
                 return $argument === 'call_' . $callCount++;
             }));
 
@@ -1104,7 +1110,7 @@ final class MockObjectTest extends TestCase
     }
 
     /**
-     * @requires PHP > 8.0
+     * @requires PHP 8
      */
     public function testUnionReturnTypeIsDoubledCorrectly(): void
     {
@@ -1115,7 +1121,7 @@ final class MockObjectTest extends TestCase
     }
 
     /**
-     * @requires PHP > 8.0
+     * @requires PHP 8
      */
     public function testNullableUnionReturnTypeIsDoubledCorrectly(): void
     {
@@ -1126,7 +1132,7 @@ final class MockObjectTest extends TestCase
     }
 
     /**
-     * @requires PHP > 8.0
+     * @requires PHP 8
      */
     public function testMixedReturnTypeIsDoubledCorrectly(): void
     {
@@ -1137,7 +1143,7 @@ final class MockObjectTest extends TestCase
     }
 
     /**
-     * @requires PHP > 8.0
+     * @requires PHP 8
      */
     public function testStaticReturnTypeIsDoubledCorrectly(): void
     {
@@ -1148,7 +1154,7 @@ final class MockObjectTest extends TestCase
     }
 
     /**
-     * @requires PHP > 8.0
+     * @requires PHP 8
      */
     public function testUnionReturnTypeWithStaticIsDoubledCorrectly(): void
     {
@@ -1159,7 +1165,7 @@ final class MockObjectTest extends TestCase
     }
 
     /**
-     * @requires PHP > 8.0
+     * @requires PHP 8
      */
     public function testNullableStaticReturnTypeIsDoubledCorrectly(): void
     {
@@ -1183,6 +1189,46 @@ final class MockObjectTest extends TestCase
         $this->assertSame('value', $object->value());
     }
 
+    /**
+     * @requires PHP 8
+     */
+    public function testMethodThatReturnsIntOrFalseCanBeStubbed(): void
+    {
+        $i = $this->createStub(InterfaceWithMethodsThatDeclareBooleanReturnTypes::class);
+
+        $i->method('returnsIntOrFalse')->willReturn(false);
+
+        $this->assertFalse($i->returnsIntOrFalse());
+
+        $i = $this->createStub(InterfaceWithMethodsThatDeclareBooleanReturnTypes::class);
+
+        $i->method('returnsIntOrFalse')->willReturn(1);
+
+        $this->assertSame(1, $i->returnsIntOrFalse());
+    }
+
+    /**
+     * @requires PHP 8
+     */
+    public function testReturnValueCanBeAutomaticallyGeneratedForMethodThatReturnsIntOrFalse(): void
+    {
+        $i = $this->createStub(InterfaceWithMethodsThatDeclareBooleanReturnTypes::class);
+
+        $this->assertFalse($i->returnsIntOrFalse());
+    }
+
+    /**
+     * @requires PHP 8
+     */
+    public function testMethodThatReturnsBoolCanBeStubbed(): void
+    {
+        $i = $this->createStub(InterfaceWithMethodsThatDeclareBooleanReturnTypes::class);
+
+        $i->method('returnsBool')->willReturn(false);
+
+        $this->assertFalse($i->returnsBool());
+    }
+
     private function resetMockObjects(): void
     {
         $refl = new ReflectionObject($this);
