@@ -113,7 +113,7 @@ class TestCaseTest extends TestCase
         $this->assertInstanceOf(Reorderable::class, $this);
 
         $this->assertEquals(
-            [new ExecutionOrderDependency(get_class($this), 'testCaseDefaultExecutionOrderDependencies')],
+            [new ExecutionOrderDependency(static::class, 'testCaseDefaultExecutionOrderDependencies')],
             $this->provides()
         );
 
@@ -1102,7 +1102,8 @@ class TestCaseTest extends TestCase
         $this->assertArrayHasKey(DependencyOnClassTest::class . '::testThatDependsOnASuccessfulClass', $result->passed());
 
         // Confirm the test depending on the failing TestSuite::class has been warn-skipped
-        $skipped = array_map(static function (TestFailure $t) {
+        $skipped = array_map(static function (TestFailure $t)
+        {
             return $t->getTestName();
         }, $result->skipped());
         $this->assertContains(DependencyOnClassTest::class . '::testThatDependsOnAFailingClass', $skipped);
